@@ -103,7 +103,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = 'beta.api.oceanbolt.com'
+    DEFAULT_ENDPOINT = 'api.oceanbolt.com'
     DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
         DEFAULT_ENDPOINT
     )
